import React, { useState, useEffect } from 'react';

const DreamArchitect = () => {
  // Game state
  const [creativity, setCreativity] = useState(0);
  const [clickPower, setClickPower] = useState(1);
  const [autoCreativity, setAutoCreativity] = useState(0);
  const [dreamLevel, setDreamLevel] = useState(1);
  const [lastTick, setLastTick] = useState(Date.now());
  const [showParticle, setShowParticle] = useState(false);
  const [particlePosition, setParticlePosition] = useState({ x: 0, y: 0 });
  const [coreAnimating, setCoreAnimating] = useState(false);
  const [activeTab, setActiveTab] = useState('elements');
  const [showAchievement, setShowAchievement] = useState(false);
  const [achievementText, setAchievementText] = useState('');
  const [totalClicks, setTotalClicks] = useState(0);
  const [totalCreativity, setTotalCreativity] = useState(0);
  const [prestigePoints, setPrestigePoints] = useState(0);
  const [showStats, setShowStats] = useState(false);
  const [randomEvent, setRandomEvent] = useState(null);
  const [dreamFragments, setDreamFragments] = useState(0); // Starting with 0 fragments
  const [gameStartTime] = useState(Date.now());
  const [prestigeCount, setPrestigeCount] = useState(0);
  const [highestProduction, setHighestProduction] = useState(0);
  const [totalElementsBought, setTotalElementsBought] = useState(0);
  const [totalUpgradesBought, setTotalUpgradesBought] = useState(0);
  const [settings, setSettings] = useState({
    particles: true,
    notifications: true,
    sfxVolume: 50,
    musicVolume: 30
  });
  
  // Debug mode state
  const [debugMode, setDebugMode] = useState(false);
  const [showDebugPanel, setShowDebugPanel] = useState(false);
  const [debugValues, setDebugValues] = useState({
    creativity: 0,
    clickPower: 1,
    dreamLevel: 1,
    dreamFragments: 0,
    prestigePoints: 0
  });
  
  // Dream Essence shop
  const [productionMultiplier, setProductionMultiplier] = useState(0);
  const [clickEfficiency, setClickEfficiency] = useState(0);
  const [startingResourcesAmount, setStartingResourcesAmount] = useState(0);
  
  const [essenceUpgrades, setEssenceUpgrades] = useState([
    { id: 1, name: 'Production Multiplier', description: 'Increases all production by 25% per level', cost: 1, count: 0, effect: (level) => `+${level * 25}% production` },
    { id: 2, name: 'Click Efficiency', description: 'Increases click power by 50% per level', cost: 1, count: 0, effect: (level) => `+${level * 50}% click power` },
    { id: 3, name: 'Starting Resources', description: 'Start with more creativity after awakening', cost: 2, count: 0, effect: (level) => `Start with ${level * 100} creativity` },
    { id: 4, name: 'Element Discount', description: 'Reduces element costs by 5% per level', cost: 3, count: 0, effect: (level) => `${level * 5}% cheaper elements` }
  ]);

  // Dream elements
  const [elements, setElements] = useState([
    { id: 1, name: 'Character', count: 0, baseCost: 10, production: 0.5, description: 'A dream inhabitant that generates creativity', unlocked: true },
    { id: 2, name: 'Landscape', count: 0, baseCost: 50, production: 3, description: 'Dreamscapes that inspire more creativity', unlocked: true },
    { id: 3, name: 'Emotion', count: 0, baseCost: 200, production: 10, description: 'Powerful feelings that fuel creative dreams', unlocked: true },
    { id: 4, name: 'Narrative', count: 0, baseCost: 1000, production: 25, description: 'Stories that weave through the dreamscape', unlocked: false },
    { id: 5, name: 'Symbol', count: 0, baseCost: 5000, production: 100, description: 'Powerful dream symbols with deep meaning', unlocked: false },
    { id: 6, name: 'Archetype', count: 0, baseCost: 25000, production: 500, description: 'Fundamental patterns of the collective unconscious', unlocked: false },
    { id: 7, name: 'Dreamscape', count: 0, baseCost: 100000, production: 2000, description: 'Entire realms within the dream world', unlocked: false },
    { id: 8, name: 'Dream Guardian', count: 0, baseCost: 500000, production: 10000, description: 'Protectors of the dream that amplify its power', unlocked: false },
  ]);
  
  // Achievements with rewards - defined separately for simpler reference in component
  const achievementDefinitions = [
    { id: 1, name: 'First Steps', description: 'Click the dream core 50 times', reward: 50, checkFn: (state) => state.totalClicks >= 50 },
    { id: 2, name: 'Dream Weaver', description: 'Purchase 10 characters', reward: 100, checkFn: (state) => state.elements.find(e => e.id === 1)?.count >= 10 },
    { id: 3, name: 'Landscape Artist', description: 'Purchase 10 landscapes', reward: 200, checkFn: (state) => state.elements.find(e => e.id === 2)?.count >= 10 },
    { id: 4, name: 'Emotional Intelligence', description: 'Purchase 10 emotions', reward: 300, checkFn: (state) => state.elements.find(e => e.id === 3)?.count >= 10 },
    { id: 5, name: 'Storyteller', description: 'Purchase 10 narratives', reward: 500, checkFn: (state) => state.elements.find(e => e.id === 4)?.count >= 10 },
    { id: 6, name: 'Dream Master', description: 'Reach 1,000 creativity per second', reward: 1000, checkFn: (state) => state.autoCreativity >= 1000 },
    { id: 7, name: 'Inception', description: 'Reach dream level 3', reward: 750, checkFn: (state) => state.dreamLevel >= 3 },
    { id: 8, name: 'Million Dreams', description: 'Generate 1,000,000 total creativity', reward: 2000, checkFn: (state) => state.totalCreativity >= 1000000 },
  ];
  
  // Initialize achievements with state from definitions
  const [achievements, setAchievements] = useState(
    achievementDefinitions.map(def => ({
      ...def,
      earned: false,
      rewardClaimed: false,
      requirement: () => def.checkFn({
        totalClicks,
        elements,
        autoCreativity,
        dreamLevel,
        totalCreativity
      })
    }))
  );
  
  // Upgrades with simpler state management
  const [upgrades, setUpgrades] = useState([
    { id: 1, name: 'Creative Spark', baseCost: 100, count: 0, unlocked: true, effect: 'Doubles click power',
       unlockCondition: () => true },
    { id: 2, name: 'Character Focus', baseCost: 300, count: 0, unlocked: false, effect: 'Characters produce 2x creativity',
       unlockCondition: () => elements.find(e => e.id === 1).count >= 10 },
    { id: 3, name: 'Landscape Enhancement', baseCost: 1000, count: 0, unlocked: false, effect: 'Landscapes produce 2x creativity',
       unlockCondition: () => elements.find(e => e.id === 2).count >= 10 },
    { id: 4, name: 'Emotional Depth', baseCost: 3000, count: 0, unlocked: false, effect: 'Emotions produce 2x creativity and unlock Narratives',
       unlockCondition: () => elements.find(e => e.id === 3).count >= 10 },
    { id: 5, name: 'Dream Evolution', baseCost: 5000, count: 0, unlocked: false, effect: 'Evolves your dream to the next level and unlocks Symbols',
       unlockCondition: () => elements.find(e => e.id === 4)?.count >= 5 },
    { id: 6, name: 'Collective Unconscious', baseCost: 20000, count: 0, unlocked: false, effect: 'Unlocks Archetypes, the most powerful dream elements',
       unlockCondition: () => elements.find(e => e.id === 5)?.count >= 5 },
    { id: 7, name: 'Dream Fragments', baseCost: 50000, count: 0, unlocked: false, effect: 'Convert excess creativity into dream fragments',
       unlockCondition: () => autoCreativity >= 500 },
    { id: 8, name: 'Lucid Dreaming', baseCost: 100000, count: 0, unlocked: false, effect: 'Increases all production by 25%',
       unlockCondition: () => dreamLevel >= 3 },
    { id: 9, name: 'Dream Recall', baseCost: 200000, count: 0, unlocked: false, effect: 'Clicking generates 10% of your per-second creativity',
       unlockCondition: () => autoCreativity >= 1000 },
  ]);
  
  // Random events
  const randomEvents = [
    { id: 1, name: 'Lucid Dream', description: 'You suddenly become aware you\'re dreaming! Double creativity production for 30 seconds.',
       effect: () => {
        setAutoCreativity(prev => prev * 2);
        setTimeout(() => {
          setAutoCreativity(prev => prev / 2);
          setRandomEvent(null);
        }, 30000);
      }
     },
    { id: 2, name: 'Nightmare', description: 'A shadow creeps into your dream. Clicking gives 5x creativity for 20 seconds!',
       effect: () => {
        setClickPower(prev => prev * 5);
        setTimeout(() => {
          setClickPower(prev => prev / 5);
          setRandomEvent(null);
        }, 20000);
      }
     },
    { id: 3, name: 'Dream Cascade', description: 'Ideas flow freely! Gain 1000 creativity instantly!',
       effect: () => {
        setCreativity(prev => prev + 1000);
        setTimeout(() => setRandomEvent(null), 5000);
      }
     },
  ];
  
  // Background colors for dream evolution
  const dreamBackgrounds = [
    'bg-indigo-100',
    'bg-indigo-200',
    'bg-purple-200',
    'bg-purple-300',
    'bg-pink-300',
    'bg-violet-300',
    'bg-fuchsia-300',
  ];
  
  // Dream core animations and visuals for each level
  const dreamCoreStyles = [
    { outer: 'from-purple-600 to-pink-500', inner: 'from-indigo-500 to-purple-600' },
    { outer: 'from-purple-700 to-pink-600', inner: 'from-indigo-600 to-purple-700' },
    { outer: 'from-purple-800 to-pink-700', inner: 'from-indigo-700 to-purple-800' },
    { outer: 'from-violet-700 to-fuchsia-600', inner: 'from-purple-700 to-violet-800' },
    { outer: 'from-violet-800 to-fuchsia-700', inner: 'from-purple-800 to-violet-900' },
    { outer: 'from-indigo-800 to-violet-900', inner: 'from-blue-800 to-indigo-900' },
    { outer: 'from-blue-900 to-violet-950', inner: 'from-indigo-900 to-purple-950' },
  ];
  
  // Background particles
  const [dreamParticles, setDreamParticles] = useState([]);
  
  // Generate background particles
  useEffect(() => {
    if (!settings.particles) return; // Don't generate particles if turned off
    
    const particleInterval = setInterval(() => {
      // Only show if autoCreativity is at least 10
      if (autoCreativity < 10) return;
      
      // Create a new particle
      const newParticle = {
        id: Math.random(),
        x: Math.random() * 100,
        y: Math.random() * 100,
        size: Math.random() * 4 + 2,
        opacity: Math.random() * 0.7 + 0.3,
        duration: Math.random() * 8 + 4
      };
      
      setDreamParticles(prev => [...prev, newParticle]);
      
      // Remove after animation completes
      setTimeout(() => {
        setDreamParticles(prev => prev.filter(p => p.id !== newParticle.id));
      }, newParticle.duration * 1000);
    }, 1000 / Math.min(10, Math.max(1, Math.floor(autoCreativity / 100)))); // More particles as production increases
    
    return () => clearInterval(particleInterval);
  }, [autoCreativity, settings.particles]);
  
  // Auto production particles
  const [productionParticles, setProductionParticles] = useState([]);
  
  // Show automatic production particles
  useEffect(() => {
    if (autoCreativity < 1 || !settings.particles) return;
    
    const productionInterval = setInterval(() => {
      // Create a new particle
      const angle = Math.random() * Math.PI * 2;
      const distance = 30 + Math.random() * 40;
      const newParticle = {
        id: Math.random(),
        x: 50 + Math.cos(angle) * distance,
        y: 50 + Math.sin(angle) * distance,
        value: formatNumber(autoCreativity / 10)
      };
      
      setProductionParticles(prev => [...prev, newParticle]);
      
      // Remove after animation completes
      setTimeout(() => {
        setProductionParticles(prev => prev.filter(p => p.id !== newParticle.id));
      }, 2000);
    }, 2000);
    
    return () => clearInterval(productionInterval);
  }, [autoCreativity, settings.particles]);
  
  // Calculate cost for an element
  const calculateElementCost = (element) => {
    const elementDiscount = essenceUpgrades.find(u => u.id === 4)?.count * 0.05 || 0;
    return Math.floor(element.baseCost * Math.pow(1.15 * (1 - elementDiscount), element.count));
  };

  // Calculate cost for an upgrade
  const calculateUpgradeCost = (upgrade) => {
    return Math.floor(upgrade.baseCost * Math.pow(3, upgrade.count));
  };
  
  // Debug key handler
  useEffect(() => {
    const handleKeyDown = (e) => {
      // Ctrl+F1 toggles debug mode
      if (e.ctrlKey && e.key === 'F1') {
        setDebugMode(!debugMode);
        setShowDebugPanel(!debugMode);
        
        // Initialize debug values
        setDebugValues({
          creativity: creativity,
          clickPower: clickPower,
          dreamLevel: dreamLevel,
          dreamFragments: dreamFragments,
          prestigePoints: prestigePoints
        });
        
        if (!debugMode && settings.notifications) {
          showAchievementNotification("Debug Mode Activated!");
        } else if (debugMode && settings.notifications) {
          showAchievementNotification("Debug Mode Deactivated");
        }
      }
    };
    
    window.addEventListener('keydown', handleKeyDown);
    return () => window.removeEventListener('keydown', handleKeyDown);
  }, [debugMode, creativity, clickPower, dreamLevel, dreamFragments, prestigePoints, settings.notifications]);
  
  // Chance for random event every 60 seconds
  useEffect(() => {
    const eventCheck = setInterval(() => {
      // 5% chance for random event
      if (Math.random() < 0.05 && !randomEvent) {
        const selectedEvent = randomEvents[Math.floor(Math.random() * randomEvents.length)];
        setRandomEvent(selectedEvent);
        selectedEvent.effect();
        
        if (settings.notifications) {
          showAchievementNotification(`${selectedEvent.name} event started!`);
        }
      }
    }, 60000);
    
    return () => clearInterval(eventCheck);
  }, [randomEvent, settings.notifications]);
  
  // Game tick for auto production
  useEffect(() => {
    const gameLoop = setInterval(() => {
      const now = Date.now();
      const deltaTime = (now - lastTick) / 1000; // Convert to seconds
      setLastTick(now);
      
      if (autoCreativity > 0) {
        const newCreativity = autoCreativity * deltaTime;
        setCreativity(prev => prev + newCreativity);
        setTotalCreativity(prev => prev + newCreativity);
      }
      
      // Check for achievements
      checkAchievements();
      
      // Unlock higher tiers based on production
      if (autoCreativity >= 5000 && !elements.find(e => e.id === 7).unlocked) {
        setElements(prev => prev.map(e => e.id === 7 ? {...e, unlocked: true} : e));
        if (settings.notifications) {
          showAchievementNotification("Dreamscapes unlocked!");
        }
      }
      
      if (autoCreativity >= 20000 && !elements.find(e => e.id === 8).unlocked) {
        setElements(prev => prev.map(e => e.id === 8 ? {...e, unlocked: true} : e));
        if (settings.notifications) {
          showAchievementNotification("Dream Guardians unlocked!");
        }
      }
    }, 100);
    
    return () => clearInterval(gameLoop);
  }, [autoCreativity, lastTick, settings.notifications, totalClicks, totalCreativity, dreamLevel, elements]);
  
  // Effect to recalculate auto creativity whenever elements change
  useEffect(() => {
    let newTotal = elements.reduce((total, element) => {
      return total + (element.count * element.production);
    }, 0);
    
    // Apply prestige bonus (10% per prestige point)
    if (prestigePoints > 0) {
      newTotal *= (1 + prestigePoints * 0.1);
    }
    
    // Apply production multiplier from essence shop
    if (productionMultiplier > 0) {
      newTotal *= (1 + productionMultiplier * 0.25);
    }
    
    setAutoCreativity(newTotal);
  }, [elements, prestigePoints, productionMultiplier]);
  
  // Track highest production rate
  useEffect(() => {
    if (autoCreativity > highestProduction) {
      setHighestProduction(autoCreativity);
    }
  }, [autoCreativity, highestProduction]);
  
  // Update stats panel regularly
  useEffect(() => {
    const statsInterval = setInterval(() => {
      // Force stats to update
      setShowStats(prev => {
        if (prev) {
          setShowStats(true);
        }
        return prev;
      });
    }, 1000);
    
    return () => clearInterval(statsInterval);
  }, []);
  
  // Check for unlocks based on element counts - run this on each game tick
  useEffect(() => {
    // Find the elements we need to check
    const characters = elements.find(e => e.id === 1);
    const landscapes = elements.find(e => e.id === 2);
    const emotions = elements.find(e => e.id === 3);
    const narratives = elements.find(e => e.id === 4);
    const symbols = elements.find(e => e.id === 5);
    
    // Update elements unlocked status based on counts
    if (characters.count >= 10) {
      const characterUpgrade = upgrades.find(u => u.id === 2);
      if (characterUpgrade && !characterUpgrade.unlocked) {
        setUpgrades(prev => prev.map(u => u.id === 2 ? {...u, unlocked: true} : u));
      }
    }
    
    if (landscapes.count >= 10) {
      const landscapeUpgrade = upgrades.find(u => u.id === 3);
      if (landscapeUpgrade && !landscapeUpgrade.unlocked) {
        setUpgrades(prev => prev.map(u => u.id === 3 ? {...u, unlocked: true} : u));
      }
    }
    
    if (emotions.count >= 10) {
      const emotionUpgrade = upgrades.find(u => u.id === 4);
      if (emotionUpgrade && !emotionUpgrade.unlocked) {
        setUpgrades(prev => prev.map(u => u.id === 4 ? {...u, unlocked: true} : u));
        setElements(prev => prev.map(e => e.id === 4 ? {...e, unlocked: true} : e));
      }
    }
    
    if (narratives && narratives.count >= 5) {
      const dreamUpgrade = upgrades.find(u => u.id === 5);
      if (dreamUpgrade && !dreamUpgrade.unlocked) {
        setUpgrades(prev => prev.map(u => u.id === 5 ? {...u, unlocked: true} : u));
        setElements(prev => prev.map(e => e.id === 5 ? {...e, unlocked: true} : e));
      }
    }
    
    if (symbols && symbols.count >= 5) {
      const collectiveUpgrade = upgrades.find(u => u.id === 6);
      if (collectiveUpgrade && !collectiveUpgrade.unlocked) {
        setUpgrades(prev => prev.map(u => u.id === 6 ? {...u, unlocked: true} : u));
        setElements(prev => prev.map(e => e.id === 6 ? {...e, unlocked: true} : e));
      }
    }
  }, [elements, upgrades]);
  
  // Apply upgrade effects when an upgrade is purchased
  const applyUpgradeEffect = (upgradeId) => {
    switch(upgradeId) {
      case 1: // Creative Spark
        setClickPower(prev => prev * 2);
        break;
      case 2: // Character Focus
        setElements(prev => prev.map(element => 
           element.id === 1 
             ? {...element, production: element.production * 2}
             : element
        ));
        break;
      case 3: // Landscape Enhancement
        setElements(prev => prev.map(element => 
           element.id === 2
            ? {...element, production: element.production * 2}
             : element
        ));
        break;
      case 4: // Emotional Depth
        setElements(prev => prev.map(element => {
          if (element.id === 3) return {...element, production: element.production * 2};
          if (element.id === 4 && !element.unlocked) return {...element, unlocked: true};
          return element;
        }));
        break;
      case 5: // Dream Evolution
        setDreamLevel(prev => Math.min(prev + 1, dreamBackgrounds.length - 1));
        setElements(prev => prev.map(element => 
           element.id === 5 && !element.unlocked
            ? {...element, unlocked: true}
             : element
        ));
        if (settings.notifications) {
          showAchievementNotification("Dream evolved to level " + (dreamLevel + 1) + "!");
        }
        break;
      case 6: // Collective Unconscious
        setElements(prev => prev.map(element => 
           element.id === 6 && !element.unlocked
            ? {...element, unlocked: true}
             : element
        ));
        break;
      case 7: // Dream Fragments
        // Generate dream fragments periodically
        setDreamFragments(prev => prev + 10);
        // Start a separate setInterval for fragment generation
        // Note: This doesn't properly clear the interval - in a real game you'd need to store this interval ID
        setInterval(() => {
          setDreamFragments(prev => prev + Math.floor(autoCreativity * 0.01));
        }, 10000);
        break;
      case 8: // Lucid Dreaming
        // Increases all production by 25%
        setElements(prev => prev.map(element => ({
          ...element, 
          production: element.production * 1.25
        })));
        break;
      case 9: // Dream Recall
        // Clicking generates 10% of your per-second creativity
        // This is handled in the handleClick function
        break;
      default:
        break;
    }
  };
  
  // Show achievement notification
  const showAchievementNotification = (text) => {
    if (!settings.notifications) return;
    
    setAchievementText(text);
    setShowAchievement(true);
    setTimeout(() => setShowAchievement(false), 5000);
  };
  
  // Check achievements - direct implementation with the current game state
  const checkAchievements = () => {
    let newAchievements = [...achievements];
    let changed = false;
    
    // For each achievement, check if its conditions are met based on current game state
    newAchievements.forEach((achievement, index) => {
      if (!achievement.earned) {
        // Directly call checkFn with current game state
        const isCompleted = achievement.checkFn({
          totalClicks,
          elements, 
          autoCreativity,
          dreamLevel,
          totalCreativity
        });
        
        if (isCompleted) {
          // Mark as earned
          newAchievements[index] = {...achievement, earned: true};
          changed = true;
          
          // Show notification
          if (settings.notifications) {
            showAchievementNotification("Achievement unlocked: " + achievement.name);
            showAchievementNotification(`Reward: ${achievement.reward} Dream Fragments!`);
          }
        }
      }
    });
    
    if (changed) {
      setAchievements(newAchievements);
    }
  };
  
  // Handle clicking the dream core
  const handleClick = (e) => {
    // Base click value
    let clickValue = clickPower;
    
    // Add percentage of auto-production if Dream Recall upgrade is purchased
    const dreamRecallUpgrade = upgrades.find(u => u.id === 9);
    if (dreamRecallUpgrade && dreamRecallUpgrade.count > 0) {
      clickValue += autoCreativity * 0.1;
    }
    
    setCreativity(prev => prev + clickValue);
    setTotalCreativity(prev => prev + clickValue);
    setTotalClicks(prev => prev + 1);
    
    // Create click particle effect
    const rect = e.target.getBoundingClientRect();
    const x = e.clientX - rect.left;
    const y = e.clientY - rect.top;
    setParticlePosition({ x, y });
    setShowParticle(true);
    
    // Trigger dream core animation
    setCoreAnimating(true);
    setTimeout(() => {
      setShowParticle(false);
      setCoreAnimating(false);
    }, 300);
    
    // Check achievements
    checkAchievements();
  };
  
  // Buy a dream element
  const buyElement = (id) => {
    const elementToBuy = elements.find(element => element.id === id);
    const cost = calculateElementCost(elementToBuy);
    
    if (creativity >= cost) {
      // Update creativity
      setCreativity(prev => prev - cost);
      
      // Update elements
      setElements(prev => prev.map(element => 
         element.id === id
           ? {...element, count: element.count + 1}
           : element
      ));
      
      // Track total elements bought
      setTotalElementsBought(prev => prev + 1);
      
      // Check unlock conditions directly
      const newCount = elementToBuy.count + 1;
      
      // Direct unlock logic after purchase
      if (id === 1 && newCount >= 10) {
        // Unlock Character Focus upgrade
        setUpgrades(prev => prev.map(u => u.id === 2 ? {...u, unlocked: true} : u));
      }
      
      if (id === 2 && newCount >= 10) {
        // Unlock Landscape Enhancement upgrade
        setUpgrades(prev => prev.map(u => u.id === 3 ? {...u, unlocked: true} : u));
      }
      
      if (id === 3 && newCount >= 10) {
        // Unlock Emotional Depth upgrade and Narratives element
        setUpgrades(prev => prev.map(u => u.id === 4 ? {...u, unlocked: true} : u));
        setElements(prev => prev.map(e => e.id === 4 ? {...e, unlocked: true} : e));
      }
      
      if (id === 4 && newCount >= 5) {
        // Unlock Dream Evolution upgrade
        setUpgrades(prev => prev.map(u => u.id === 5 ? {...u, unlocked: true} : u));
      }
      
      if (id === 5 && newCount >= 5) {
        // Unlock Collective Unconscious upgrade
        setUpgrades(prev => prev.map(u => u.id === 6 ? {...u, unlocked: true} : u));
      }
    }
  };
  
  // Buy an upgrade
  const buyUpgrade = (id) => {
    const upgradeToBuy = upgrades.find(upgrade => upgrade.id === id);
    const cost = calculateUpgradeCost(upgradeToBuy);
    
    if (creativity >= cost) {
      // Update creativity
      setCreativity(prev => prev - cost);
      
      // Increment upgrade count
      setUpgrades(prev => prev.map(upgrade => 
         upgrade.id === id
           ? {...upgrade, count: upgrade.count + 1}
           : upgrade
      ));
      
      // Track total upgrades bought
      setTotalUpgradesBought(prev => prev + 1);
      
      // Apply upgrade effect
      applyUpgradeEffect(id);
    }
  };
  
  // Buy essence upgrade
  const buyEssenceUpgrade = (id) => {
    const upgradeToBuy = essenceUpgrades.find(upgrade => upgrade.id === id);
    const cost = upgradeToBuy.cost;
    
    if (prestigePoints >= cost) {
      // Update essence points
      setPrestigePoints(prev => prev - cost);
      
      // Increment upgrade count
      setEssenceUpgrades(prev => prev.map(upgrade => 
         upgrade.id === id
           ? {...upgrade, count: upgrade.count + 1}
           : upgrade
      ));
      
      // Apply essence upgrade effect
      applyEssenceUpgradeEffect(id);
      
      if (settings.notifications) {
        showAchievementNotification(`Purchased ${upgradeToBuy.name}!`);
      }
    }
  };
  
  // Apply essence upgrade effects
  const applyEssenceUpgradeEffect = (id) => {
    switch(id) {
      case 1: // Production Multiplier
        setProductionMultiplier(prev => prev + 1);
        break;
      case 2: // Click Efficiency
        setClickEfficiency(prev => prev + 1);
        setClickPower((1 + clickEfficiency * 0.5) * (1 + prestigePoints * 0.1));
        break;
      case 3: // Starting Resources
        setStartingResourcesAmount(prev => prev + 100);
        break;
      case 4: // Element Discount
        // This is applied in the calculateElementCost function
        break;
      default:
        break;
    }
  };
  
  // Wake up (prestige) system
  const wakeUp = () => {
    // Calculate dream fragments based on total progress
    const newFragments = Math.floor(Math.sqrt(totalCreativity / 1000) * 100);
    
    // Add new fragments to existing ones
    setDreamFragments(prev => prev + newFragments);
    
    // Increment prestige count
    setPrestigeCount(prev => prev + 1);
    
    // Show notification
    if (settings.notifications) {
      showAchievementNotification(`You woke up with ${newFragments} dream fragments!`);
    }
    
    // Reset game state but keep achievements and prestige points
    setCreativity(startingResourcesAmount);
    setClickPower((1 + clickEfficiency * 0.5) * (1 + prestigePoints * 0.1)); // Bonus from prestige and click efficiency
    setAutoCreativity(0);
    setDreamLevel(1);
    setElements(prev => prev.map(element => ({
      ...element,
      count: 0,
      unlocked: element.id <= 3 // Only keep first 3 unlocked
    })));
    setUpgrades(prev => prev.map(upgrade => ({
      ...upgrade,
      count: 0,
      unlocked: upgrade.id === 1 // Only keep first upgrade unlocked
    })));
    
    // Keep total creativity for achievements but reset for current run
    setTotalCreativity(0);
  };
  
  // Apply debug values
  const applyDebugValues = () => {
    setCreativity(debugValues.creativity);
    setClickPower(debugValues.clickPower);
    setDreamLevel(debugValues.dreamLevel);
    setDreamFragments(debugValues.dreamFragments);
    setPrestigePoints(debugValues.prestigePoints);
    
    // Close debug panel
    setShowDebugPanel(false);
    
    if (settings.notifications) {
      showAchievementNotification("Debug values applied!");
    }
  };
  
  // Format large numbers
  const formatNumber = (num) => {
    if (num < 1000) return num.toFixed(1);
    if (num < 1000000) return (num/1000).toFixed(1) + 'K';
    return (num/1000000).toFixed(1) + 'M';
  };
  
  // Format play time
  const formatPlayTime = (milliseconds) => {
    const seconds = Math.floor(milliseconds / 1000);
    const minutes = Math.floor(seconds / 60);
    const hours = Math.floor(minutes / 60);
    
    if (hours > 0) {
      return `${hours}h ${minutes % 60}m ${seconds % 60}s`;
    } else if (minutes > 0) {
      return `${minutes}m ${seconds % 60}s`;
    } else {
      return `${seconds}s`;
    }
  };
  
  return (
    <div className="flex flex-col min-h-screen w-screen bg-gray-100 overflow-hidden select-none">
      <style jsx>{`
        @keyframes float-up {
          0% { opacity: 1; transform: translateY(0); }
          100% { opacity: 0; transform: translateY(-30px); }
        }
        @keyframes float {
          0% { transform: translateY(0) translateX(0); }
          50% { transform: translateY(-10px) translateX(5px); }
          100% { transform: translateY(0) translateX(0); }
        }
        .animate-float-up {
          animation: float-up 2s ease-out forwards;
        }
      `}</style>
      
      {/* Header */}
      <div className="bg-purple-800 text-white p-4 shadow-md w-full">
        <div className="max-w-6xl mx-auto flex justify-between items-center">
          <div>
            <h1 className="text-2xl font-bold">Dream Architect</h1>
            <div className="text-lg">
              Creativity: {formatNumber(creativity)} 
              <span className="text-sm ml-4">
                (per second: {formatNumber(autoCreativity)})
              </span>
            </div>
          </div>
          <div className="flex space-x-2">
            {prestigePoints > 0 && (
              <div className="px-3 py-1 bg-purple-700 rounded-lg flex items-center">
                <span className="text-sm font-medium">Dream Essence: {prestigePoints}</span>
              </div>
            )}
            {dreamFragments > 0 && (
              <div className="px-3 py-1 bg-indigo-700 rounded-lg flex items-center">
                <span className="text-sm font-medium">Fragments: {dreamFragments}</span>
              </div>
            )}
            {debugMode && (
              <div className="px-3 py-1 bg-red-600 rounded-lg flex items-center">
                <span className="text-sm font-medium">DEBUG MODE</span>
              </div>
            )}
          </div>
        </div>
      </div>
      
      {/* Main Game Area */}
      <div className="flex flex-1 max-w-6xl mx-auto w-full overflow-hidden">
        {/* Dream Visualization */}
        <div className={`flex-1 flex items-center justify-center relative ${dreamBackgrounds[Math.min(dreamLevel - 1, dreamBackgrounds.length - 1)]}`}>
          <div 
             className={`w-40 h-40 rounded-full bg-gradient-to-r ${dreamCoreStyles[Math.min(dreamLevel - 1, dreamCoreStyles.length - 1)].outer} cursor-pointer transform hover:scale-105 flex items-center justify-center shadow-lg transition-all duration-150 ${coreAnimating ? 'scale-95 animate-pulse' : ''}`}
            onClick={handleClick}
          >
            <div className={`w-32 h-32 rounded-full bg-gradient-to-r ${dreamCoreStyles[Math.min(dreamLevel - 1, dreamCoreStyles.length - 1)].inner} flex items-center justify-center shadow-inner transition-all duration-150 ${coreAnimating ? 'shadow-xl' : ''}`}>
              <div className="text-white font-bold">Dream Core</div>
            </div>
            
            {/* Click particle effect */}
            {showParticle && (
              <div 
                 className="absolute text-yellow-400 text-lg font-bold animate-ping"
                style={{ left: particlePosition.x, top: particlePosition.y }}
              >
                +{clickPower.toFixed(1)}
              </div>
            )}
          </div>
          
          {/* Background dream particles */}
          {settings.particles && dreamParticles.map(particle => (
            <div
              key={particle.id}
              className="absolute rounded-full bg-white"
              style={{
                left: `${particle.x}%`,
                top: `${particle.y}%`,
                width: `${particle.size}px`,
                height: `${particle.size}px`,
                opacity: particle.opacity,
                animation: `float ${particle.duration}s linear infinite`,
                boxShadow: '0 0 6px rgba(255, 255, 255, 0.8)'
              }}
            />
          ))}
          
          {/* Auto production particles */}
          {settings.particles && productionParticles.map(particle => (
            <div
              key={particle.id}
              className="absolute text-green-300 text-sm font-medium animate-float-up"
              style={{
                left: `${particle.x}%`,
                top: `${particle.y}%`,
              }}
            >
              +{particle.value}
            </div>
          ))}
          
          <div className="flex flex-col space-y-1 absolute top-5 right-5">
            <button
               className="px-4 py-2 bg-purple-700 text-white rounded-lg text-sm hover:bg-purple-800 transition-colors"
              onClick={() => setShowStats(!showStats)}
            >
              Stats
            </button>
            {totalCreativity >= 1000000 && (
              <button 
                 className="px-4 py-2 bg-indigo-700 text-white rounded-lg text-sm hover:bg-indigo-800 transition-colors"
                onClick={wakeUp}
              >
                Wake Up (+{Math.floor(Math.sqrt(totalCreativity / 1000) * 100)} fragments)
              </button>
            )}
          </div>
          
          {/* Achievement notification */}
          {showAchievement && (
            <div className="absolute top-20 left-1/2 transform -translate-x-1/2 bg-purple-800 text-white px-4 py-2 rounded-lg shadow-lg animate-bounce">
              {achievementText}
            </div>
          )}
          
          {/* Random event notification */}
          {randomEvent && (
            <div className="absolute bottom-10 left-1/2 transform -translate-x-1/2 bg-indigo-900 text-white px-4 py-2 rounded-lg shadow-lg">
              <p className="font-bold">{randomEvent.name}</p>
              <p className="text-sm">{randomEvent.description}</p>
            </div>
          )}
          
          {/* Debug panel */}
          {showDebugPanel && (
            <div className="absolute inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50" onClick={() => setShowDebugPanel(false)}>
              <div className="bg-white p-6 rounded-lg w-96" onClick={e => e.stopPropagation()}>
                <div className="flex justify-between items-center mb-4">
                  <h2 className="text-xl font-bold text-red-600">Debug Mode</h2>
                  <span className="text-xs bg-red-100 text-red-800 px-2 py-1 rounded-full">Ctrl+F1 to toggle</span>
                </div>
                
                <div className="space-y-4">
                  <div>
                    <label className="block text-sm font-medium text-gray-700 mb-1">Creativity</label>
                    <input
                      type="number"
                      value={debugValues.creativity}
                      onChange={e => setDebugValues({...debugValues, creativity: Number(e.target.value)})}
                      className="w-full p-2 border border-gray-300 rounded-md"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium text-gray-700 mb-1">Click Power</label>
                    <input
                      type="number"
                      value={debugValues.clickPower}
                      onChange={e => setDebugValues({...debugValues, clickPower: Number(e.target.value)})}
                      className="w-full p-2 border border-gray-300 rounded-md"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium text-gray-700 mb-1">Dream Level (1-{dreamBackgrounds.length})</label>
                    <input
                      type="number"
                      min="1"
                      max={dreamBackgrounds.length}
                      value={debugValues.dreamLevel}
                      onChange={e => setDebugValues({...debugValues, dreamLevel: Number(e.target.value)})}
                      className="w-full p-2 border border-gray-300 rounded-md"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium text-gray-700 mb-1">Dream Fragments</label>
                    <input
                      type="number"
                      value={debugValues.dreamFragments}
                      onChange={e => setDebugValues({...debugValues, dreamFragments: Number(e.target.value)})}
                      className="w-full p-2 border border-gray-300 rounded-md"
                    />
                  </div>
                  
                  <div>
                    <label className="block text-sm font-medium text-gray-700 mb-1">Dream Essence</label>
                    <input
                      type="number"
                      value={debugValues.prestigePoints}
                      onChange={e => setDebugValues({...debugValues, prestigePoints: Number(e.target.value)})}
                      className="w-full p-2 border border-gray-300 rounded-md"
                    />
                  </div>
                </div>
                
                <div className="mt-6 flex space-x-3">
                  <button 
                    className="flex-1 px-4 py-2 bg-red-600 text-white rounded-lg hover:bg-red-700"
                    onClick={applyDebugValues}
                  >
                    Apply Changes
                  </button>
                  <button 
                    className="flex-1 px-4 py-2 bg-gray-300 text-gray-700 rounded-lg hover:bg-gray-400"
                    onClick={() => setShowDebugPanel(false)}
                  >
                    Cancel
                  </button>
                </div>
              </div>
            </div>
          )}
          
          {/* Stats modal */}
          {showStats && (
            <div className="absolute inset-0 bg-black bg-opacity-50 flex items-center justify-center" onClick={() => setShowStats(false)}>
              <div className="bg-white p-6 rounded-lg w-96 max-h-[80vh] overflow-y-auto" onClick={e => e.stopPropagation()}>
                <h2 className="text-xl font-bold mb-4 text-purple-800">Dream Statistics</h2>
                <div className="grid grid-cols-2 gap-4 mb-6">
                  <div className="bg-indigo-50 p-3 rounded-lg text-center">
                    <p className="text-xs text-indigo-700 uppercase font-semibold mb-1">Total Creativity</p>
                    <p className="text-xl font-bold text-indigo-900">{formatNumber(totalCreativity)}</p>
                  </div>
                  <div className="bg-purple-50 p-3 rounded-lg text-center">
                    <p className="text-xs text-purple-700 uppercase font-semibold mb-1">Production</p>
                    <p className="text-xl font-bold text-purple-900">{formatNumber(autoCreativity)}/s</p>
                  </div>
                  <div className="bg-pink-50 p-3 rounded-lg text-center">
                    <p className="text-xs text-pink-700 uppercase font-semibold mb-1">Click Power</p>
                    <p className="text-xl font-bold text-pink-900">{formatNumber(clickPower)}</p>
                  </div>
                  <div className="bg-blue-50 p-3 rounded-lg text-center">
                    <p className="text-xs text-blue-700 uppercase font-semibold mb-1">Dream Level</p>
                    <p className="text-xl font-bold text-blue-900">{dreamLevel}</p>
                  </div>
                </div>
                
                <div className="mb-4">
                  <p className="font-medium mb-1">Total Clicks: {totalClicks}</p>
                  <p className="font-medium mb-1">Total Creativity: {formatNumber(totalCreativity)}</p>
                  <p className="font-medium mb-1">Dream Level: {dreamLevel}</p>
                  <p className="font-medium mb-1">Dream Essence: {prestigePoints}</p>
                  <p className="font-medium mb-1">Dream Fragments: {dreamFragments}</p>
                  <p className="font-medium mb-1">Highest Creativity/sec: {formatNumber(highestProduction)}</p>
                  <p className="font-medium mb-1">Total Elements Purchased: {totalElementsBought}</p>
                  <p className="font-medium mb-1">Total Upgrades Purchased: {totalUpgradesBought}</p>
                  <p className="font-medium mb-1">Times Awakened: {prestigeCount}</p>
                  <p className="font-medium mb-1">Play Time: {formatPlayTime(Date.now() - gameStartTime)}</p>
                </div>
                
                <div className="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                  <div className="bg-gray-50 p-3 rounded-lg">
                    <h4 className="text-sm font-semibold text-gray-700 mb-2">Production Breakdown</h4>
                    {elements.filter(e => e.count > 0).map(element => (
                      <div key={element.id} className="flex justify-between mb-1 text-sm">
                        <span className="text-gray-600">{element.name} ({element.count})</span>
                        <span className="font-medium">{formatNumber(element.count * element.production)}/s</span>
                      </div>
                    ))}
                    {elements.filter(e => e.count > 0).length === 0 && (
                      <p className="text-sm text-gray-500 italic">No elements purchased yet</p>
                    )}
                    <div className="mt-2 pt-2 border-t border-gray-200 flex justify-between font-medium">
                      <span>Total Production</span>
                      <span>{formatNumber(autoCreativity)}/s</span>
                    </div>
                  </div>
                  
                  <div className="bg-gray-50 p-3 rounded-lg">
                    <h4 className="text-sm font-semibold text-gray-700 mb-2">Upgrade Effects</h4>
                    {upgrades.filter(u => u.count > 0).map(upgrade => (
                      <div key={upgrade.id} className="flex justify-between mb-1 text-sm">
                        <span className="text-gray-600">{upgrade.name}</span>
                        <span className="font-medium">Level {upgrade.count}</span>
                      </div>
                    ))}
                    {upgrades.filter(u => u.count > 0).length === 0 && (
                      <p className="text-sm text-gray-500 italic">No upgrades purchased yet</p>
                    )}
                    <div className="mt-2 pt-2 border-t border-gray-200 flex justify-between text-sm">
                      <span>Prestige Bonus</span>
                      <span>{prestigePoints > 0 ? `+${prestigePoints * 10}%` : 'None'}</span>
                    </div>
                  </div>
                </div>
                
                <h3 className="text-lg font-bold mb-2 text-purple-700">Achievements</h3>
                <div className="grid gap-2">
                  {achievements.map(achievement => (
                    <div 
                       key={achievement.id}
                       className={`p-2 rounded-lg ${achievement.earned ? 'bg-purple-100' : 'bg-gray-100'}`}
                    >
                      <div className="flex justify-between items-start">
                        <div>
                          <p className={`font-medium ${achievement.earned ? 'text-purple-800' : 'text-gray-500'}`}>
                            {achievement.name}
                          </p>
                          <p className="text-xs text-gray-600">{achievement.description}</p>
                          <p className="text-xs text-indigo-600 mt-1">Reward: {achievement.reward} dream fragments</p>
                        </div>
                        {achievement.earned && !achievement.rewardClaimed && (
                          <button 
                             className="px-2 py-1 bg-indigo-600 text-white rounded-lg text-xs"
                            onClick={() => {
                              // Claim the reward
                              setDreamFragments(prev => prev + achievement.reward);
                              setAchievements(prev => prev.map(a => 
                                 a.id === achievement.id ? {...a, rewardClaimed: true} : a
                              ));
                              showAchievementNotification(`Claimed ${achievement.reward} dream fragments!`);
                            }}
                          >
                            Claim
                          </button>
                        )}
                        {achievement.earned && achievement.rewardClaimed && (
                          <span className="text-xs text-green-600 font-medium">Claimed</span>
                        )}
                        {!achievement.earned && (
                          <span className="text-xs text-gray-500">Incomplete</span>
                        )}
                      </div>
                    </div>
                  ))}
                </div>
                
                <button 
                  className="mt-4 px-4 py-2 bg-purple-600 text-white rounded-lg hover:bg-purple-700 w-full"
                  onClick={() => setShowStats(false)}
                >
                  Close
                </button>
              </div>
            </div>
          )}
        </div>
        
        {/* Shop Panel */}
        <div className="w-80 bg-white flex flex-col h-full text-gray-800">
          {/* Tab Navigation - Scrollable */}
          <div className="overflow-x-auto border-b border-gray-200 relative">
            <div className="flex whitespace-nowrap px-4 pt-4">
              <button 
                 className={`py-2 px-4 font-medium flex-shrink-0 ${activeTab === 'elements'
                   ? 'text-purple-800 border-b-2 border-purple-500'
                   : 'text-gray-500 hover:text-purple-800'}`}
                onClick={() => setActiveTab('elements')}
              >
                Dream Elements
              </button>
              <button 
                 className={`py-2 px-4 font-medium flex-shrink-0 ${activeTab === 'upgrades'
                   ? 'text-purple-800 border-b-2 border-purple-500'
                   : 'text-gray-500 hover:text-purple-800'}`}
                onClick={() => setActiveTab('upgrades')}
              >
                Dream Upgrades
              </button>
              <button 
                 className={`py-2 px-4 font-medium flex-shrink-0 ${activeTab === 'achievements'
                   ? 'text-purple-800 border-b-2 border-purple-500'
                   : 'text-gray-500 hover:text-purple-800'}`}
                onClick={() => setActiveTab('achievements')}
              >
                Achievements
              </button>
              <button 
                 className={`py-2 px-4 font-medium flex-shrink-0 ${activeTab === 'fragments'
                   ? 'text-purple-800 border-b-2 border-purple-500'
                   : 'text-gray-500 hover:text-purple-800'}`}
                onClick={() => setActiveTab('fragments')}
              >
                Dream Fragments
              </button>
              <button 
                 className={`py-2 px-4 font-medium flex-shrink-0 ${activeTab === 'essence'
                   ? 'text-purple-800 border-b-2 border-purple-500'
                   : 'text-gray-500 hover:text-purple-800'}`}
                onClick={() => setActiveTab('essence')}
              >
                Dream Essence
              </button>
            </div>
            {/* Scroll indicator */}
            <div className="absolute top-0 right-0 bottom-0 w-8 pointer-events-none bg-gradient-to-l from-white to-transparent" />
          </div>

          {/* Tab Content Area - Scrollable */}
          <div className="overflow-y-auto flex-1 p-4">
            {activeTab === 'elements' ? (
              <div>
                <h2 className="text-xl font-bold mb-2 text-purple-800 border-b border-purple-200 sticky top-0 bg-white">Dream Elements</h2>
                {elements.filter(element => element.unlocked).map(element => (
                  <div key={element.id} className="mb-3 bg-gray-50 p-2 rounded-lg">
                    <div className="flex justify-between items-center">
                      <div>
                        <div className="font-bold text-gray-800">{element.name}</div>
                        <div className="text-xs text-gray-600">{element.description}</div>
                        <div className="text-sm text-gray-700">Owned: {element.count}</div>
                        <div className="text-sm text-gray-700">Produces: {element.production} per second</div>
                        <div className="text-sm text-gray-700">Total: {formatNumber(element.count * element.production)} per second</div>
                      </div>
                      <button
                        className={`px-3 py-1 rounded-lg text-white text-sm ${
                          creativity >= calculateElementCost(element)
                             ? 'bg-purple-600 hover:bg-purple-700'
                             : 'bg-gray-400'
                        }`}
                        onClick={() => buyElement(element.id)}
                        disabled={creativity < calculateElementCost(element)}
                      >
                        Buy {formatNumber(calculateElementCost(element))}
                      </button>
                    </div>
                  </div>
                ))}
              </div>
            ) : activeTab === 'upgrades' ? (
              <div>
                <h2 className="text-xl font-bold mb-2 text-purple-800 border-b border-purple-200 sticky top-0 bg-white">Dream Upgrades</h2>
                {upgrades.map(upgrade => {
                  // For Dream Evolution and Collective Unconscious, don't allow multiple purchases
                  const isOnePurchaseOnly = upgrade.id === 5 || upgrade.id === 6;
                  const showBuyButton = !isOnePurchaseOnly || (isOnePurchaseOnly && upgrade.count === 0);
                  
                  return (
                    (upgrade.unlocked || upgrade.unlockCondition()) && (
                      <div key={upgrade.id} className="mb-3 p-2 rounded-lg bg-gray-50">
                        <div className="flex justify-between items-center">
                          <div>
                            <div className="font-bold text-gray-800">{upgrade.name} {upgrade.count > 0 && !isOnePurchaseOnly ? `(Level ${upgrade.count})` : ""}</div>
                            <div className="text-xs text-gray-600">{upgrade.effect}</div>
                            {upgrade.count > 0 && !isOnePurchaseOnly && (
                              <div className="text-xs text-green-600 mt-1">
                                Current level: {upgrade.count}
                               </div>
                            )}
                            {upgrade.count > 0 && isOnePurchaseOnly && (
                              <div className="text-xs text-green-600 mt-1">
                                Unlocked
                              </div>
                            )}
                          </div>
                          {showBuyButton ? (
                            <button
                              className={`px-3 py-1 rounded-lg text-white text-sm ${
                                creativity >= calculateUpgradeCost(upgrade)
                                   ? 'bg-indigo-600 hover:bg-indigo-700'
                                   : 'bg-gray-400'
                              }`}
                              onClick={() => buyUpgrade(upgrade.id)}
                              disabled={creativity < calculateUpgradeCost(upgrade)}
                            >
                              Buy {formatNumber(calculateUpgradeCost(upgrade))}
                            </button>
                          ) : (
                            <div className="text-sm font-medium text-green-600">Purchased</div>
                          )}
                        </div>
                      </div>
                    )
                  );
                })}
              </div>
            ) : activeTab === 'achievements' ? (
              <div>
                <h2 className="text-xl font-bold mb-2 text-purple-800 border-b border-purple-200 sticky top-0 bg-white">Achievements</h2>
                {achievements.map(achievement => (
                  <div 
                     key={achievement.id}
                     className={`mb-3 p-2 rounded-lg ${achievement.earned ? 'bg-purple-100' : 'bg-gray-100'}`}
                  >
                    <div className="flex justify-between items-center">
                      <div>
                        <p className={`font-medium ${achievement.earned ? 'text-purple-800' : 'text-gray-500'}`}>
                          {achievement.name}
                        </p>
                        <p className="text-xs text-gray-600">{achievement.description}</p>
                        <p className="text-xs text-indigo-600">Reward: {achievement.reward} dream fragments</p>
                      </div>
                      <div>
                        {achievement.earned ? (
                          achievement.rewardClaimed ? 
                            <span className="text-xs font-medium text-green-600">Completed</span> :
                            <button 
                              className="px-2 py-1 bg-indigo-600 text-white rounded-lg text-xs"
                              onClick={() => {
                                setDreamFragments(prev => prev + achievement.reward);
                                setAchievements(prev => 
                                  prev.map(a => a.id === achievement.id ? {...a, rewardClaimed: true} : a)
                                );
                                showAchievementNotification(`Claimed ${achievement.reward} dream fragments!`);
                              }}
                            >
                              Claim
                            </button>
                        ) : (
                          <span className="text-xs text-gray-500">Incomplete</span>
                        )}
                      </div>
                    </div>
                  </div>
                ))}
                
                <div className="mt-6">
                  <h3 className="text-lg font-bold mb-2 text-purple-800">Statistics</h3>
                  <div className="bg-gray-50 p-3 rounded-lg">
                    <p className="text-sm mb-1">Total Clicks: {totalClicks}</p>
                    <p className="text-sm mb-1">Total Creativity: {formatNumber(totalCreativity)}</p>
                    <p className="text-sm mb-1">Dream Level: {dreamLevel}</p>
                    <p className="text-sm mb-1">Dream Essence: {prestigePoints}</p>
                    <p className="text-sm mb-1">Times Awakened: {prestigeCount}</p>
                    <p className="text-sm">Play Time: {formatPlayTime(Date.now() - gameStartTime)}</p>
                  </div>
                  
                  {totalCreativity >= 1000000 && (
                    <button 
                       className="mt-4 px-4 py-2 bg-indigo-700 text-white rounded-lg text-sm hover:bg-indigo-800 transition-colors w-full"
                      onClick={wakeUp}
                    >
                      Wake Up (+{Math.floor(Math.sqrt(totalCreativity / 1000) * 100)} fragments)
                    </button>
                  )}
                </div>
              </div>
            ) : activeTab === 'fragments' ? (
              <div>
                <h2 className="text-xl font-bold mb-2 text-purple-800 border-b border-purple-200 sticky top-0 bg-white">Dream Fragments</h2>
                <div className="mb-4 p-3 bg-indigo-50 rounded-lg">
                  <p className="text-lg font-medium text-indigo-800">Current Fragments: {dreamFragments}</p>
                  <p className="text-sm text-indigo-600 mt-1">Fragments can be used to purchase special dream items</p>
                  <div className="mt-3 h-2 bg-indigo-200 rounded-full overflow-hidden">
                    <div 
                       className="h-full bg-indigo-600 transition-all duration-300"
                      style={{ width: `${Math.min(dreamFragments / 10, 100)}%` }}
                    />
                  </div>
                  <div className="flex justify-between text-xs text-indigo-600 mt-1">
                    <span>0</span>
                    <span>1000 fragments</span>
                  </div>
                </div>
                
                <div className="mb-4">
                  <h3 className="text-lg font-medium mb-2 text-purple-800">Fragment Shop</h3>
                  <div className="grid gap-3">
                    <div className="p-2 bg-gray-50 rounded-lg flex justify-between items-center">
                      <div>
                        <p className="font-medium text-gray-800">Dream Accelerator</p>
                        <p className="text-xs text-gray-600">Boosts creativity production by 25% for 1 hour</p>
                      </div>
                      <button 
                         className={`px-3 py-1 rounded-lg text-white text-sm ${
                          dreamFragments >= 100
                             ? 'bg-indigo-600 hover:bg-indigo-700'
                             : 'bg-gray-400'
                        }`}
                        onClick={() => {
                          if (dreamFragments >= 100) {
                            setDreamFragments(prev => prev - 100);
                            // Apply boost logic here
                            showAchievementNotification("Dream Accelerator activated!");
                          }
                        }}
                        disabled={dreamFragments < 100}
                      >
                        Buy (100)
                      </button>
                    </div>
                    
                    <div className="p-2 bg-gray-50 rounded-lg flex justify-between items-center">
                      <div>
                        <p className="font-medium text-gray-800">Creativity Cache</p>
                        <p className="text-xs text-gray-600">Instantly gain 10,000 creativity</p>
                      </div>
                      <button 
                         className={`px-3 py-1 rounded-lg text-white text-sm ${
                          dreamFragments >= 250
                             ? 'bg-indigo-600 hover:bg-indigo-700'
                             : 'bg-gray-400'
                        }`}
                        onClick={() => {
                          if (dreamFragments >= 250) {
                            setDreamFragments(prev => prev - 250);
                            setCreativity(prev => prev + 10000);
                            showAchievementNotification("Added 10,000 creativity!");
                          }
                        }}
                        disabled={dreamFragments < 250}
                      >
                        Buy (250)
                      </button>
                    </div>
                    
                    <div className="p-2 bg-gray-50 rounded-lg flex justify-between items-center">
                      <div>
                        <p className="font-medium text-gray-800">Dream Surge</p>
                        <p className="text-xs text-gray-600">+50% click power for 30 minutes</p>
                      </div>
                      <button 
                         className={`px-3 py-1 rounded-lg text-white text-sm ${
                          dreamFragments >= 150
                             ? 'bg-indigo-600 hover:bg-indigo-700'
                             : 'bg-gray-400'
                        }`}
                        onClick={() => {
                          if (dreamFragments >= 150) {
                            setDreamFragments(prev => prev - 150);
                            setClickPower(prev => prev * 1.5);
                            showAchievementNotification("Dream Surge activated!");
                            setTimeout(() => {
                              setClickPower(prev => prev / 1.5);
                              showAchievementNotification("Dream Surge ended");
                            }, 30 * 60 * 1000); // 30 minutes
                          }
                        }}
                        disabled={dreamFragments < 150}
                      >
                        Buy (150)
                      </button>
                    </div>
                    
                    <div className="p-2 bg-gray-50 rounded-lg flex justify-between items-center">
                      <div>
                        <p className="font-medium text-gray-800">Lucid Enhancer</p>
                        <p className="text-xs text-gray-600">Doubles dream evolution effect for 15 minutes</p>
                      </div>
                      <button 
                         className={`px-3 py-1 rounded-lg text-white text-sm ${
                          dreamFragments >= 300
                             ? 'bg-indigo-600 hover:bg-indigo-700'
                             : 'bg-gray-400'
                        }`}
                        onClick={() => {
                          if (dreamFragments >= 300) {
                            setDreamFragments(prev => prev - 300);
                            setDreamLevel(prev => Math.min(prev + 1, dreamBackgrounds.length - 1));
                            showAchievementNotification("Lucid Enhancer activated!");
                            setTimeout(() => {
                              setDreamLevel(prev => Math.max(prev - 1, 1));
                              showAchievementNotification("Lucid Enhancer ended");
                            }, 15 * 60 * 1000); // 15 minutes
                          }
                        }}
                        disabled={dreamFragments < 300}
                      >
                        Buy (300)
                      </button>
                    </div>
                    
                    <div className="p-2 bg-gray-50 rounded-lg flex justify-between items-center">
                      <div>
                        <p className="font-medium text-gray-800">Dream Essence Converter</p>
                        <p className="text-xs text-gray-600">Turn 500 dream fragments into 1 dream essence</p>
                      </div>
                      <button 
                         className={`px-3 py-1 rounded-lg text-white text-sm ${
                          dreamFragments >= 500
                             ? 'bg-indigo-600 hover:bg-indigo-700'
                             : 'bg-gray-400'
                        }`}
                        onClick={() => {
                          if (dreamFragments >= 500) {
                            setDreamFragments(prev => prev - 500);
                            setPrestigePoints(prev => prev + 1);
                            showAchievementNotification("Converted to 1 Dream Essence!");
                          }
                        }}
                        disabled={dreamFragments < 500}
                      >
                        Buy (500)
                      </button>
                    </div>
                  </div>
                </div>
              </div>
            ) : activeTab === 'essence' ? (
              <div>
                <h2 className="text-xl font-bold mb-2 text-purple-800 border-b border-purple-200 sticky top-0 bg-white">Dream Essence</h2>
                
                <div className="mb-4 p-3 bg-purple-50 rounded-lg">
                  <p className="text-lg font-medium text-purple-800">Current Essence: {prestigePoints}</p>
                  <p className="text-sm text-purple-600 mt-1">Essence is gained when you wake up from dreams</p>
                  <div className="flex items-center mt-2 text-sm text-purple-700">
                    <div className="mr-2 flex-shrink-0 h-2 w-2 bg-purple-600 rounded-full"></div>
                    <p>Current production bonus: +{prestigePoints * 10}%</p>
                  </div>
                </div>
                
                <div className="mb-4">
                  <h3 className="text-lg font-medium mb-2 text-purple-800">Permanent Upgrades</h3>
                  <div className="grid gap-3">
                    {essenceUpgrades.map(upgrade => (
                      <div key={upgrade.id} className="p-3 bg-gray-50 rounded-lg">
                        <div className="flex justify-between items-start mb-2">
                          <div>
                            <p className="font-medium text-gray-800">{upgrade.name}</p>
                            <p className="text-xs text-gray-600">{upgrade.description}</p>
                          </div>
                          <div className="bg-purple-100 text-purple-800 text-xs font-medium px-2 py-1 rounded-full">
                            Level {upgrade.count}
                          </div>
                        </div>
                        <div className="flex justify-between items-center">
                          <p className="text-sm text-green-600">{upgrade.effect(upgrade.count)}</p>
                          <button 
                            className={`px-3 py-1 rounded-lg text-white text-sm ${
                              prestigePoints >= upgrade.cost
                                ? 'bg-purple-600 hover:bg-purple-700'
                                : 'bg-gray-400'
                            }`}
                            onClick={() => buyEssenceUpgrade(upgrade.id)}
                            disabled={prestigePoints < upgrade.cost}
                          >
                            Upgrade ({upgrade.cost})
                          </button>
                        </div>
                      </div>
                    ))}
                  </div>
                </div>
                
                {totalCreativity >= 1000000 && (
                  <button 
                    className="w-full px-4 py-2 bg-indigo-700 text-white rounded-lg text-sm hover:bg-indigo-800 transition-colors"
                    onClick={wakeUp}
                  >
                    Wake Up (+{Math.floor(Math.sqrt(totalCreativity / 1000) * 100)} fragments)
                  </button>
                )}
              </div>
            ) : activeTab === 'settings' ? (
              <div>
                <h2 className="text-xl font-bold mb-2 text-purple-800 border-b border-purple-200 sticky top-0 bg-white">Settings</h2>
                
                <div className="grid gap-4 mt-3">
                  <div className="flex items-center justify-between">
                    <label className="text-gray-700">Background Particles</label>
                    <div 
                       className={`w-12 h-6 rounded-full ${settings.particles ? 'bg-purple-600' : 'bg-gray-300'} relative transition-colors cursor-pointer`}
                      onClick={() => setSettings(prev => ({...prev, particles: !prev.particles}))}
                    >
                      <div 
                         className={`absolute top-1 w-4 h-4 rounded-full bg-white transition-all ${settings.particles ? 'left-7' : 'left-1'}`}
                       />
                    </div>
                  </div>
                  
                  <div className="flex items-center justify-between">
                    <label className="text-gray-700">Notifications</label>
                    <div 
                       className={`w-12 h-6 rounded-full ${settings.notifications ? 'bg-purple-600' : 'bg-gray-300'} relative transition-colors cursor-pointer`}
                      onClick={() => setSettings(prev => ({...prev, notifications: !prev.notifications}))}
                    >
                      <div 
                         className={`absolute top-1 w-4 h-4 rounded-full bg-white transition-all ${settings.notifications ? 'left-7' : 'left-1'}`}
                       />
                    </div>
                  </div>
                  
                  <div>
                    <label className="text-gray-700 block mb-1">SFX Volume</label>
                    <input 
                       type="range"
                       min="0"
                       max="100"
                       value={settings.sfxVolume}
                       onChange={e => setSettings(prev => ({...prev, sfxVolume: parseInt(e.target.value)}))}
                      className="w-full h-2 rounded-lg appearance-none bg-gray-300 focus:outline-none focus:bg-gray-400"
                    />
                    <div className="text-right text-xs text-gray-500">{settings.sfxVolume}%</div>
                  </div>
                  
                  <div>
                    <label className="text-gray-700 block mb-1">Music Volume</label>
                    <input 
                       type="range"
                       min="0"
                       max="100"
                       value={settings.musicVolume}
                       onChange={e => setSettings(prev => ({...prev, musicVolume: parseInt(e.target.value)}))}
                      className="w-full h-2 rounded-lg appearance-none bg-gray-300 focus:outline-none focus:bg-gray-400"
                    />
                    <div className="text-right text-xs text-gray-500">{settings.musicVolume}%</div>
                  </div>
                  
                  <div className="mt-4">
                    <button className="w-full py-2 bg-purple-600 text-white rounded-lg hover:bg-purple-700 transition-colors">
                      Save Settings
                    </button>
                  </div>
                </div>
              </div>
            ) : null}
          </div>
        </div>
      </div>
    </div>
  );
};

export default DreamArchitect;